#' Selection of Accounts for Audit in Example 6.11 
#' 
#' @name audit
#' @docType data
#' @format Data frame with the following 6 variables: 
#' \describe{
#'   \item{account}{audit unit}
#'   \item{bookval}{book value of account}
#'   \item{cumbv}{cumulative book value}
#'   \item{rn1}{random number 1 selecting account}
#'   \item{rn2}{random number 2 selecting account}
#'   \item{rn3}{random number 3 selecting account}
#' }
#' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
#'   439.
"audit"